@@ -17,9 +17,6 @@
 bool snek_interactive;
 
 bool snek_parse_middle;
-static uint8_t for_depth;
-
-static bool snek_print_val;
 
 uint8_t snek_parse_nformal;
 uint8_t snek_parse_nnamed;
@@ -39,6 +36,10 @@ snek_token_val_t snek_token_val;
 #define snek_no_dict 0
 #endif
 
+#define PARSE_TOP \
+	uint8_t for_depth = 0; \
+	bool snek_print_val = 0;
+
 #define GRAMMAR_TABLE
 #ifdef PARSE_DEBUG
 #define TOKEN_NAMES
@@ -208,6 +209,12 @@ static inline void unop_second(void)
 	snek_code_add_op(value_pop().op);
 }
 
+static inline void bool_branch(snek_op_t op)
+{
+	snek_code_add_op_offset(op, 0);
+	value_push_offset(snek_compile_prev);
+}
+
 #define PARSE_CODE
 #include "snek-gram.h"
 
@@ -225,7 +232,6 @@ snek_parse(void)
 		/* Reset parse state */
 		snek_parse_middle = false;
 		value_stack_p = 0;
-		for_depth = 0;
 
 		/* Reset codegen state */
 		snek_code_reset();
